import * as i1 from '@angular/common/http';
import { HttpClient, HttpErrorResponse, HttpClientModule } from '@angular/common/http';
import * as i0 from '@angular/core';
import { InjectionToken, Injectable, Inject, NgModule } from '@angular/core';
import { catchError } from 'rxjs';
import * as i2 from '@angular/router';

var CbmInvoiceModel;
(function (CbmInvoiceModel) {
    let EPaymentTerm;
    (function (EPaymentTerm) {
        EPaymentTerm["CREDIT"] = "credit";
        EPaymentTerm["DEBIT"] = "debit";
    })(EPaymentTerm = CbmInvoiceModel.EPaymentTerm || (CbmInvoiceModel.EPaymentTerm = {}));
    let EInvoiceType;
    (function (EInvoiceType) {
        EInvoiceType["GENERAL"] = "general";
        EInvoiceType["EXPORT"] = "export";
    })(EInvoiceType = CbmInvoiceModel.EInvoiceType || (CbmInvoiceModel.EInvoiceType = {}));
    (function (EPaymentTerm) {
        function fromString(value) {
            switch (value) {
                case 'credit':
                    return EPaymentTerm.CREDIT;
                case 'debit':
                    return EPaymentTerm.DEBIT;
                default:
                    throw new Error(`Invalid value ${value}`);
            }
        }
        EPaymentTerm.fromString = fromString;
        function toString(value) {
            switch (value) {
                case EPaymentTerm.CREDIT:
                    return 'credit';
                case EPaymentTerm.DEBIT:
                    return 'debit';
                default:
                    throw new Error(`Invalid value ${value}`);
            }
        }
        EPaymentTerm.toString = toString;
    })(EPaymentTerm = CbmInvoiceModel.EPaymentTerm || (CbmInvoiceModel.EPaymentTerm = {}));
})(CbmInvoiceModel || (CbmInvoiceModel = {}));

class InvoiceHttpInterceptorHandler {
    constructor(next, interceptor) {
        this.next = next;
        this.interceptor = interceptor;
    }
    handle(req) {
        return this.interceptor.intercept(req, this.next);
    }
}
class InvoiceHandlerService {
    constructor(backend, injector, interceptors) {
        this.backend = backend;
        this.injector = injector;
        this.interceptors = interceptors;
        this.chain = null;
    }
    handle(req) {
        if (this.chain === null) {
            const interceptors = this.injector.get(this.interceptors, []);
            this.chain = interceptors.reduceRight((next, interceptor) => new InvoiceHttpInterceptorHandler(next, interceptor), this.backend);
        }
        return this.chain.handle(req);
    }
}
const INVOICE_HTTP_INTERCEPTORS = new InjectionToken('INVOICE_HTTP_INTERCEPTORS');
class InvoiceHttpService extends HttpClient {
    constructor(backend, injector) {
        super(new InvoiceHandlerService(backend, injector, INVOICE_HTTP_INTERCEPTORS));
        this.injector = injector;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: InvoiceHttpService, deps: [{ token: i1.HttpBackend }, { token: i0.Injector }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: InvoiceHttpService }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: InvoiceHttpService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.HttpBackend }, { type: i0.Injector }] });
class InvoiceAuthInterceptor {
    constructor(moduleConfig, router) {
        this.moduleConfig = moduleConfig;
        this.router = router;
    }
    intercept(req, next) {
        const authToken = localStorage.getItem('tokenGlobal');
        const { baseUrl } = this.moduleConfig;
        const update = {
            url: `${baseUrl}/${req.url}`,
        };
        if (authToken) {
            update.headers = req.headers.set('Authorization', `Bearer ${authToken}`);
        }
        const authReq = req.clone(update);
        return next.handle(authReq).pipe(catchError((error) => {
            if (error instanceof HttpErrorResponse && error.status === 401) {
                this.router.navigate(['auth', 'login']);
            }
            throw error;
        }));
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: InvoiceAuthInterceptor, deps: [{ token: INVOICE_MODULE_CONFIG }, { token: i2.Router }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: InvoiceAuthInterceptor }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: InvoiceAuthInterceptor, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: undefined, decorators: [{
                    type: Inject,
                    args: [INVOICE_MODULE_CONFIG]
                }] }, { type: i2.Router }] });

class CbmInvoiceService {
    constructor(http) {
        this.http = http;
    }
    list(params) {
        return this.http.get('', {
            params: params,
        });
    }
    getOne(id) {
        return this.http.get(id);
    }
    save(data) {
        return this.http.post('', data);
    }
    changeStatus(id, data) {
        return this.http.put(`change-status/${id}`, data);
    }
    downloadExcel(params) {
        return this.http.get('download/excel', {
            params: params,
            observe: 'response',
            responseType: 'blob',
        });
    }
    downloadIndividualPdf(id, params) {
        return this.http.get(`download/pdf/individual/${id}`, {
            params: params,
            observe: 'response',
            responseType: 'blob',
        });
    }
    downloadIndividualExcel(id, params) {
        return this.http.get(`download/excel/individual/${id}`, {
            params: params,
            observe: 'response',
            responseType: 'blob',
        });
    }
    sendEmail(id, params) {
        return this.http.get(`sent-email/${id}`, {
            params: params,
        });
    }
    listWithoutRetention(params) {
        return this.http.get('list/invoice-for-retention', {
            params: params,
        });
    }
    listLastMovements(params) {
        return this.http.get('last-movement/inventory', {
            params: params,
        });
    }
    generateOrRegenerateSeat(invoiceId) {
        return this.http.get(`generate-or-regenerate-seat/${invoiceId}`);
    }
    createXml(id) {
        return this.http.get(`create-xml/${id}`);
    }
    downloadXml(id) {
        return this.http.get(`download-xml/${id}`, {
            observe: 'response',
            responseType: 'blob',
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: CbmInvoiceService, deps: [{ token: InvoiceHttpService }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: CbmInvoiceService }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: CbmInvoiceService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: InvoiceHttpService }] });

class CbmInvoiceRepository {
    constructor(service) {
        this.service = service;
    }
    list(params) {
        return this.service.list(params);
    }
    getOne(id) {
        return this.service.getOne(id);
    }
    save(data) {
        return this.service.save(data);
    }
    changeStatus(id, data) {
        return this.service.changeStatus(id, data);
    }
    downloadExcel(params) {
        return this.service.downloadExcel(params);
    }
    downloadIndividualPdf(id, params) {
        return this.service.downloadIndividualPdf(id, params);
    }
    downloadIndividualExcel(id, params) {
        return this.service.downloadIndividualExcel(id, params);
    }
    sendEmail(id, params) {
        return this.service.sendEmail(id, params);
    }
    listWithoutRetention(params) {
        return this.service.listWithoutRetention(params);
    }
    listLastMovements(params) {
        return this.service.listLastMovements(params);
    }
    generateOrRegenerateSeat(invoiceId) {
        return this.service.generateOrRegenerateSeat(invoiceId);
    }
    createXml(id) {
        return this.service.createXml(id);
    }
    downloadXml(id) {
        return this.service.downloadXml(id);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: CbmInvoiceRepository, deps: [{ token: CbmInvoiceService }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: CbmInvoiceRepository }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: CbmInvoiceRepository, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: CbmInvoiceService }] });

const INVOICE_MODULE_CONFIG = new InjectionToken('INVOICE_MODULE_CONFIG');
class CbmInvoiceModule {
    static forRoot(config) {
        return {
            ngModule: CbmInvoiceModule,
            providers: [
                InvoiceAuthInterceptor,
                {
                    provide: INVOICE_MODULE_CONFIG,
                    useValue: config,
                },
                {
                    provide: INVOICE_HTTP_INTERCEPTORS,
                    useClass: InvoiceAuthInterceptor,
                    multi: true,
                },
                InvoiceHttpService,
                CbmInvoiceService,
                CbmInvoiceRepository,
            ],
        };
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: CbmInvoiceModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "17.3.5", ngImport: i0, type: CbmInvoiceModule, imports: [HttpClientModule] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: CbmInvoiceModule, imports: [HttpClientModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.5", ngImport: i0, type: CbmInvoiceModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [HttpClientModule],
                }]
        }] });

/*
 * Public API Surface of invoice-repository
 */

/**
 * Generated bundle index. Do not edit.
 */

export { CbmInvoiceModel, CbmInvoiceModule, CbmInvoiceRepository, CbmInvoiceService, INVOICE_MODULE_CONFIG };
//# sourceMappingURL=g2-common-invoice-repository.mjs.map
