import { CbmSalePriceModel } from '@g2-common/sale-price-repository';
export declare namespace CbmInvoiceModel {
    type DetailType = 'item' | 'service' | 'kit' | 'outsourcing_service';
    enum EPaymentTerm {
        CREDIT = "credit",
        DEBIT = "debit"
    }
    enum EInvoiceType {
        GENERAL = "general",
        EXPORT = "export"
    }
    namespace EPaymentTerm {
        function fromString(value: string): EPaymentTerm;
        function toString(value: EPaymentTerm): TPaymentTerm;
    }
    type TPaymentTerm = `${EPaymentTerm}`;
    type TInvoiceType = `${EInvoiceType}`;
    interface ListParams {
        page: number;
        size: number;
        reverse_status?: boolean;
        company_branch_id?: string;
        user_id?: string;
        to_date?: number;
        from_date?: number;
        enabled?: boolean;
        export?: boolean;
        invoice_type?: TInvoiceType;
        sequential?: string;
        invoice_number?: string;
        state?: string;
        client_branch_id?: string;
        client_id?: string;
        seller_id?: string;
        payment_term?: TPaymentTerm;
    }
    interface ListResponse {
        success: boolean;
        pageNum: number;
        pageSize: number;
        pages: number;
        total: number;
        items: ListResponse.Item[];
    }
    namespace ListResponse {
        interface Item {
            _id: string;
            company_id: string;
            company_branch_id: string;
            client_id: string;
            client_category_id: string;
            contact_id: string;
            seller_id: string;
            document_date: number;
            document_nomenclature: string;
            document_sequence: string;
            document_number: string;
            SRI_state: string;
            document_state: string;
            document_branch_identification_number: string;
            document_emission_point_id?: string;
            document_emission_point_number: string;
            document_correlative: string;
            authorization_number: string;
            payment_term: string;
            tax_base: number;
            discount: number;
            service: number;
            commentary: string;
            total: number;
            price_type: string;
            client_document_number: string;
            client_document_code?: string;
            client_trade_name: string;
            client_business_name: string;
            client_phone_code: string;
            client_address: string;
            client_cellphone: string;
            client_email: string;
            client_category_name?: string;
            client_province_id?: string;
            client_canton_id?: string;
            client_parish_id?: string;
            client_province_code?: string;
            client_province_name?: string;
            client_canton_code?: string;
            client_canton_name?: string;
            client_parish_code?: string;
            client_parish_name?: string;
            seller_full_name: string;
            seller_identification_number: string;
            seller_address: string;
            seller_email: string[];
            seller_cellphone: string;
            company_NIF: string;
            company_address: string;
            company_trade_name: string;
            company_business_name: string;
            company_branch_identification_number: string;
            company_branch_trade_name: string;
            company_branch_logo: string;
            company_branch_address: string;
            company_branch_email: string;
            company_branch_cellphone: string;
            company_branch_phone: string;
            client_branch_id: string;
            client_branch_code: string;
            client_branch_name: string;
            client_branch_address: string;
            client_branch_email: string;
            client_branch_cellphone: string;
            client_branch_phone: string;
            client_branch_phone_code: string;
            contact_identification_number: string;
            contact_full_name: string;
            contact_phone_code: string;
            contact_cellphone: string;
            contact_email: string;
            default_price_list_id?: string;
            default_price_list_name?: string;
            default_price_list_type?: string;
            default_cost_center_id?: string;
            default_cost_center_code?: string;
            default_cost_center_name?: string;
            default_cost_center_father_code?: string;
            default_cost_center_father_name?: string;
            default_discount_rate?: number;
            event_module_origin?: string;
            collection_origin_name?: string;
            collection_origin_id?: string;
            document_origin_name?: string;
            document_origin_number?: string;
            document_origin_date?: number;
            document_type?: string;
            environment?: number;
            SRI_identificator?: string;
            SRI_message?: string;
            SRI_aditional_information?: string;
            SRI_response?: object;
            url_authorized_document?: string;
            SRI_authorization_date?: number;
            credit_SRI_payment_term_id?: string;
            credit_SRI_payment_term_code?: string;
            enabled: boolean;
            disabled_reason?: string;
            created_at: number;
            created_user: string;
            updated_at: number;
            updated_user: string;
            reverse_status: boolean;
            reverse_reason?: string;
            reverse_at?: number;
            reverse_user?: string;
            invoice_credit?: number;
            invoice_debit?: number;
            invoice_retention?: number;
            invoice_credit_note?: number;
            invoice_return?: number;
            invoice_balance?: number;
            addItems: boolean;
            checked?: boolean;
        }
    }
    interface GetOneResponse {
        success: boolean;
        data: GetOneResponse.Data;
    }
    namespace GetOneResponse {
        interface Data {
            _id?: string;
            company_id?: string;
            company_branch_id?: string;
            client_id?: string;
            client_category_id: string;
            client_branch_id?: string;
            contact_id?: string;
            seller_id?: string;
            type?: string;
            document_date?: number;
            document_nomenclature?: string;
            document_number?: string;
            SRI_state?: string;
            document_state?: string;
            document_branch_identification_number?: string;
            document_emission_point_number?: string;
            document_emission_point_id?: string;
            document_sequence?: string;
            authorization_number?: string;
            payment_term?: string;
            tax_base?: number;
            tax_iva?: number;
            discount?: number;
            service?: number;
            total?: number;
            commentary?: string;
            client_document_number?: string;
            client_document_code?: string;
            client_trade_name?: string;
            client_business_name?: string;
            client_phone_code?: string;
            client_category_name?: string;
            client_address?: string;
            client_cellphone?: string;
            client_email?: string;
            client_branch_code?: string;
            client_branch_name?: string;
            client_branch_address?: string;
            client_branch_email?: string;
            client_branch_cellphone?: string;
            client_branch_phone?: string;
            client_branch_phone_code?: string;
            client_province_id?: string;
            client_canton_id?: string;
            client_parish_id?: string;
            client_province_code?: string;
            client_province_name?: string;
            client_canton_code?: string;
            client_canton_name?: string;
            client_parish_code?: string;
            client_parish_name?: string;
            contact_identification_number?: string;
            contact_full_name?: string;
            contact_phone_code?: string;
            contact_cellphone?: string;
            contact_email?: string;
            seller_full_name?: string;
            seller_identification_number?: string;
            seller_address: string;
            seller_email: string[];
            seller_cellphone: string;
            company_NIF?: string;
            company_address?: string;
            company_trade_name?: string;
            company_business_name?: string;
            company_branch_identification_number?: string;
            company_branch_trade_name?: string;
            company_branch_logo?: string;
            company_branch_address?: string;
            company_branch_email?: string;
            company_branch_cellphone?: string;
            company_branch_phone?: string;
            default_price_list_id?: string;
            default_price_list_name?: string;
            default_price_list_type?: string;
            default_cost_center_id?: string;
            default_cost_center_code?: string;
            default_cost_center_name?: string;
            default_cost_center_father_code?: string;
            default_cost_center_father_name?: string;
            default_discount_rate?: number;
            export?: boolean;
            invoice_type?: TInvoiceType;
            export_data?: Data.ExportData;
            event_module_origin?: string;
            collection_origin_name?: string;
            collection_origin_id?: string;
            document_origin_name?: string;
            document_origin_number?: string;
            document_origin_date?: number;
            document_type?: string;
            environment?: number;
            SRI_identificator?: string;
            SRI_message?: string;
            SRI_aditional_information?: string;
            SRI_response?: object;
            url_authorized_document?: string;
            SRI_authorization_date?: number;
            credit_SRI_payment_term_id?: string;
            credit_SRI_payment_term_code?: string;
            enabled?: boolean;
            disabled_reason?: string;
            deleted?: boolean;
            created_at?: number;
            created_user?: string;
            updated_at?: number;
            updated_user?: string;
            reverse_status: boolean;
            reverse_reason?: string;
            reverse_at?: number;
            reverse_user?: string;
            invoice_summary_article?: Data.SummaryArticle[];
            invoice_detail?: Data.Detail[];
            invoice_tax?: Data.Tax[];
            invoice_payment_term?: Data.PaymentTerm[];
            credit_management_installment?: Data.CreditManagementInstallment[];
            credit_management_balance: number;
            additional_information?: Data.AdditionaInformation[];
            invoice_tax_declaration?: Data.TaxDeclaration[];
            income_id?: Data.Income[];
            related_documents?: Data.RelatedDocument[];
        }
        namespace Data {
            interface SummaryArticle {
                code: string;
                name: string;
                amount: number;
                sequence: string;
            }
            interface RelatedDocument {
                collection_origin_id: string;
                collection_origin_name: string;
                document_number: string;
                secuencial: string;
                date: number;
                total: number;
                _id: string;
            }
            interface TaxDeclaration {
                _id: string;
                configuration_id: string;
                raw_code?: string;
                net_code?: string;
                tax_code?: string;
                raw_value?: number;
                net_value?: number;
                tax_value?: number;
                description: string;
            }
            interface Income {
                _id?: string;
                income_id?: string;
                credit_management_id?: string;
                credit_management_detail_id?: string;
                client_id?: string;
                client_branch_id?: string;
                seller_id?: string;
                cost_center_id?: string;
                installment?: string;
                credit_document_nomenclature?: string;
                credit_document_number?: string;
                paid?: number;
                previous_balance?: number;
                subsequent_balance?: number;
                client_document_number?: string;
                client_trade_name?: string;
                client_business_name?: string;
                client_phone_code?: string;
                client_address?: string;
                client_cellphone?: string;
                client_email?: string;
                seller_identification_number?: string;
                seller_full_name?: string;
                seller_document_number?: string;
                seller_address?: string;
                seller_email?: string[];
                seller_cellphone?: string;
                cost_center_code?: string;
                cost_center_name?: string;
                client_branch_code?: string;
                client_branch_name?: string;
                client_branch_address?: string;
                client_branch_cellphone?: string;
                client_branch_phone_code?: string;
                created_user?: string;
                created_at?: number;
            }
            interface ExportData {
                export_foreign_trade: string;
                export_buyer_address: string;
                export_country_origin_id: string;
                export_country_origin_name: string;
                export_country_origin_code: string;
                export_origin_port: string;
                export_country_destination_id: string;
                export_country_destination_name: string;
                export_country_destination_code: string;
                export_destination_port: string;
                export_incoterm_place: string;
                export_incoterm_invoice_id: string;
                export_incoterm_invoice_code: string;
                export_incoterm_invoice_name: string;
                export_incoterm_without_taxes_id: string;
                export_incoterm_without_taxes_code: string;
                export_incoterm_without_taxes_name: string;
                export_international_freight: number;
                export_international_insurance: number;
                export_customs_expenditures: number;
                export_transportation_expenses: number;
                export_dae?: string;
                export_mawb?: string;
                export_forwarder?: string;
                export_cr?: string;
            }
            interface PaymentTerm {
                _id: string;
                payment_term_id: string;
                account_id?: string;
                SRI_payment_term_id: string;
                SRI_payment_term_code: string;
                financial_bank_id?: string;
                date: number;
                value: number;
                financial_bank_name?: string;
                card_type?: string;
                batch_code?: string;
                bank_cheque?: string;
                account_name?: string;
                account_code?: string;
                payment_term_code: string;
                payment_term_name: string;
                operation_number?: string;
            }
            interface Detail {
                _id: string;
                invoice_id?: string;
                item_id?: string;
                category_id?: string;
                cost_center_id?: string;
                price_list_id?: string;
                tax_iva_id?: string;
                tax_irbpn_id?: string;
                tax_ice_id?: string;
                unit_measure_id?: string;
                amount?: number;
                amount_free?: number;
                sequence?: string;
                price_base?: number;
                total_price?: number;
                discount_rate?: number;
                unit_discount?: number;
                total_discount?: number;
                replace_item_name?: string;
                commentary_item?: string;
                tax_iva_rate?: number;
                item_code?: string;
                item_barcode?: string;
                item_name?: string;
                item_balance_referal_guide?: number;
                item_balance?: number;
                unit_measure_name?: string;
                unit_measure_abbreviation?: string;
                unit_measure_group_abbreviation?: string;
                unit_measure_group_id?: string;
                unit_measure_group_name?: string;
                unit_measure_type?: string;
                unit_measure_quantity?: number;
                stock_afected?: number;
                in_stock?: number;
                manage_by?: string;
                category_name?: string;
                cost_center_code?: string;
                cost_center_name?: string;
                cost_center_father_code?: string;
                cost_center_father_name?: string;
                price_list_name?: string;
                type?: DetailType;
                price_type?: CbmSalePriceModel.TName;
                price_type_description?: string;
                price_type_id?: string;
                deleted?: boolean;
                created_at?: number;
                created_user?: string;
                updated_at?: number;
                updated_user?: string;
                invoice_detail_tax?: Detail.Tax[];
                tax_iva_code?: string;
                tax_iva?: Detail.TaxIva;
            }
            namespace Detail {
                interface Tax {
                    _id: string;
                    invoice_detail_id: string;
                    type: string;
                    description: string;
                    tax_code: string;
                    tax_rate: number;
                    tax_base: number;
                    tax_value: number;
                }
                interface TaxIva {
                    _id: string;
                    country_id?: string;
                    code?: string;
                    percentage?: number;
                    description?: string;
                    enabled?: boolean;
                    created_user?: string;
                    created_at?: number;
                    updated_user?: string;
                    updated_at?: number;
                }
            }
            interface Tax {
                _id: string;
                invoice_id: string;
                description: string;
                type: string;
                tax_code: string;
                tax_rate: number;
                tax_base: number;
                tax_value: number;
                created_at: number;
                created_user: string;
                updated_at: number;
                updated_user: string;
            }
            interface CreditManagementInstallment {
                _id: string;
                credit_management_id?: string;
                installment: string;
                date: number;
                expired_in?: number;
                period?: number;
                credit: number;
                debit?: number;
                retention?: number;
                credit_note?: number;
                return?: number;
                balance?: number;
                created_at: number;
                created_user: string;
                updated_at?: number;
                updated_user?: string;
            }
            interface AdditionaInformation {
                description: string;
                value: string;
                type: string;
            }
        }
    }
    interface SaveBody {
        invoice_type?: TInvoiceType;
        client_id: string;
        client_category_id: string;
        client_branch_id?: string;
        contact_id?: string;
        seller_id: string;
        document_type: string;
        document_emission_point_number: string;
        document_emission_point_id: string;
        payment_term: string;
        tax_base: number;
        discount: number;
        service: number;
        total: number;
        commentary: string;
        client_document_number: string;
        client_document_code: string;
        client_trade_name: string;
        client_business_name: string;
        client_phone_code: string;
        client_address: string;
        client_cellphone: string;
        client_email: string;
        client_category_name: string;
        seller_full_name: string;
        seller_identification_number: string;
        seller_address: string;
        seller_email: string[];
        seller_cellphone: string;
        company_NIF: string;
        company_address: string;
        company_trade_name: string;
        company_business_name: string;
        company_required_accounting: boolean;
        company_retention_agent: string;
        company_special_taxpayer: string;
        company_taxpayer_type: string;
        company_custom_commentary: string;
        company_branch_identification_number: string;
        company_branch_trade_name: string;
        company_branch_logo: string;
        company_branch_address: string;
        company_branch_email: string;
        company_branch_cellphone: string;
        company_branch_phone: string;
        company_branch_artisanal_qualification: string;
        client_branch_code?: string;
        client_branch_name?: string;
        client_branch_address?: string;
        client_branch_email?: string;
        client_branch_cellphone?: string;
        client_branch_phone?: string;
        client_branch_phone_code?: string;
        client_province_id?: string;
        client_canton_id?: string;
        client_parish_id?: string;
        client_province_code?: string;
        client_province_name?: string;
        client_canton_code?: string;
        client_canton_name?: string;
        client_parish_code?: string;
        client_parish_name?: string;
        contact_identification_number?: string;
        contact_full_name?: string;
        contact_phone_code?: string;
        contact_cellphone?: string;
        contact_email?: string;
        order_id?: string;
        environment: number;
        default_price_list_id?: string;
        default_price_list_name?: string;
        default_price_list_type?: string;
        default_cost_center_id?: string;
        default_cost_center_code?: string;
        default_cost_center_name?: string;
        default_cost_center_father_code?: string;
        default_cost_center_father_name?: string;
        default_discount_rate?: number;
        tax_base_iva: number;
        tax_base_iva_rate_0: number;
        tax_base_iva_exempt: number;
        tax_base_iva_not_subject: number;
        tax_base_irbpnr: number;
        tax_base_ice: number;
        tax_iva: number;
        tax_irbpnr: number;
        tax_ice: number;
        export?: boolean;
        export_data?: SaveBody.ExportData;
        event_module_origin?: string;
        collection_origin_name?: string;
        collection_origin_id?: string;
        document_origin_name?: string;
        document_origin_number?: string;
        document_origin_date?: number;
        credit_SRI_payment_term_id?: string;
        credit_SRI_payment_term_code?: string;
        invoice_summary_article?: SaveBody.SummaryArticle[];
        invoice_detail: SaveBody.Detail[];
        invoice_tax: SaveBody.Tax[];
        invoice_installment: SaveBody.Installment[];
        invoice_payment_term?: SaveBody.PaymentTerm[];
        additional_information?: SaveBody.AdditionaInformation[];
        invoice_tax_declaration: SaveBody.TaxDeclaration[];
    }
    namespace SaveBody {
        interface SummaryArticle {
            code: string;
            name: string;
            amount: number;
            sequence: string;
        }
        interface ExportData {
            export_foreign_trade: string;
            export_buyer_address: string;
            export_country_origin_id: string;
            export_country_origin_name: string;
            export_country_origin_code: string;
            export_origin_port: string;
            export_country_destination_id: string;
            export_country_destination_name: string;
            export_country_destination_code: string;
            export_destination_port: string;
            export_incoterm_place: string;
            export_incoterm_invoice_id: string;
            export_incoterm_invoice_code: string;
            export_incoterm_invoice_name: string;
            export_incoterm_without_taxes_id: string;
            export_incoterm_without_taxes_code: string;
            export_incoterm_without_taxes_name: string;
            export_international_freight: number;
            export_international_insurance: number;
            export_customs_expenditures: number;
            export_transportation_expenses: number;
            export_dae?: string;
            export_mawb?: string;
            export_forwarder?: string;
            export_cr?: string;
        }
        interface Detail {
            item_id: string;
            category_id: string;
            cost_center_id?: string;
            price_list_id: string;
            tax_iva_id: string;
            tax_iva_code: string;
            tax_irbpn_id?: string;
            tax_ice_id?: string;
            unit_measure_id?: string;
            amount: number;
            amount_free?: number;
            sequence?: string;
            price_base: number;
            total_price: number;
            discount_rate: number;
            unit_discount: number;
            total_discount: number;
            commentary_item?: string | null;
            replace_item_name?: string | null;
            tax_iva_rate: number;
            item_code: string;
            item_barcode?: string;
            item_name: string;
            unit_measure_abbreviation?: string;
            unit_measure_group_abbreviation?: string;
            unit_measure_name?: string;
            unit_measure_group_id?: string;
            unit_measure_group_name?: string;
            unit_measure_type?: string;
            unit_measure_quantity?: number;
            stock_afected?: number;
            in_stock?: number;
            manage_by?: string;
            category_name: string;
            cost_center_code?: string;
            cost_center_name?: string;
            cost_center_father_code?: string;
            cost_center_father_name?: string;
            price_list_name: string;
            type: DetailType;
            price_type?: CbmSalePriceModel.TName;
            price_type_description?: string;
            price_type_id?: string;
            invoice_detail_tax: Detail.Tax[];
        }
        interface TaxDeclaration {
            configuration_id: string;
            raw_code?: string;
            net_code?: string;
            tax_code?: string;
            raw_value?: number;
            net_value?: number;
            tax_value?: number;
            description: string;
        }
        interface AdditionaInformation {
            description: string;
            value?: string;
            type: string;
        }
        namespace Detail {
            interface Tax {
                type: string;
                description: string;
                tax_code: string;
                tax_rate: number;
                tax_base: number;
                tax_value: number;
            }
        }
        interface Tax {
            type: string;
            description: string;
            tax_code: string;
            tax_rate: number;
            tax_base: number;
            tax_value: number;
        }
        interface Installment {
            installment: string;
            date: number;
            expired_in: number;
            period: number;
            credit: number;
        }
        interface PaymentTerm {
            payment_term_id: string;
            account_id?: string;
            SRI_payment_term_id: string;
            SRI_payment_term_code: string;
            financial_bank_id?: string;
            date: number;
            value: number;
            financial_bank_name?: string;
            card_type?: string;
            batch_code?: string;
            account_name?: string;
            account_code?: string;
            bank_cheque?: string;
            payment_term_code: string;
            payment_term_name: string;
            operation_number?: string;
        }
    }
    interface DownloadExcelParams {
        payment_term?: TPaymentTerm;
        to_date?: number;
        from_date?: number;
        enabled?: boolean;
        sequential?: string;
        invoice_number?: string;
        state?: string;
        client_branch_id?: string;
        client_id?: string;
        export?: boolean;
        invoice_type?: TInvoiceType;
        reverse_status?: boolean;
    }
    interface ListLastMovementsParams {
        page: number;
        size: number;
        client_id: string;
        item_id: string;
    }
    interface ListLastMovementsResponse {
        success: boolean;
        pageNum: number;
        pageSize: number;
        pages: number;
        total: number;
        items: ListLastMovementsResponse.Item[];
        totalAmount: ListLastMovementsResponse.TotalAmount;
    }
    namespace ListLastMovementsResponse {
        interface TotalAmount {
            _id: string;
            sum_amount: number;
            sum_price_base: number;
            sum_total_price: number;
            sum_discount_rate: number;
            sum_unit_discount: number;
            sum_total_discount: number;
        }
        interface Item {
            _id: string;
            collection_origin_name: string;
            collection_origin_id: string;
            company_id: string;
            company_branch_id: string;
            country_id: string;
            item_id: string;
            category_id: string;
            cost_center_id: string;
            price_list_id: string;
            tax_iva_id: string;
            unit_measure_id: string;
            type: string;
            manage_by: string;
            amount: number;
            price_base: number;
            total_price: number;
            discount_rate: number;
            unit_discount: number;
            total_discount: number;
            commentary_item: null;
            replace_item_name: null;
            tax_iva_code: string;
            tax_iva_rate: number;
            item_code: string;
            item_barcode: string;
            item_name: string;
            unit_measure_type: string;
            unit_measure_abbreviation: string;
            unit_measure_name: string;
            unit_measure_quantity: number;
            stock_afected: number;
            category_name: string;
            cost_center_code: string;
            cost_center_name: string;
            cost_center_father_code: string;
            cost_center_father_name: string;
            price_list_name: string;
            price_type: string;
            price_type_description: string;
            price_type_id: string;
            returned_items: number;
            item_balance: number;
            item_balance_referal_guide: number;
            deleted: boolean;
            created_at: number;
            created_user: string;
            document_nomenclature: string;
            document_number: string;
            document_branch_identification_number: string;
            document_emission_point_number: string;
            document_sequence: string;
            client_document_code: string;
            client_document_number: string;
            client_trade_name: string;
            client_business_name: string;
            client_phone_code: string;
            client_address: string;
            client_cellphone: string;
            client_email: string;
            client_category_name: string;
        }
    }
    interface ListWithoutRetentionParams {
        page: number;
        size: number;
        client_id: string;
        date_end?: number;
        date_begin?: number;
        invoice_number?: string;
        payment_term?: string;
        branch_emission_point_sequence?: string;
        nomenclature_number?: string;
    }
    interface ListWithoutRetentionResponse {
        success: boolean;
        pageNum: number;
        pageSize: number;
        pages: number;
        total: number;
        items: ListWithoutRetentionResponse.Item[];
    }
    namespace ListWithoutRetentionResponse {
        interface Item {
            _id: string;
            company_id: string;
            company_branch_id: string;
            client_id: string;
            client_branch_id: string;
            contact_id: string;
            seller_id: string;
            document_nomenclature: string;
            document_number: string;
            document_date: number;
            SRI_state: string;
            document_branch_identification_number: string;
            document_emission_point_number: string;
            document_sequence: string;
            authorization_number: string;
            payment_term: string;
            tax_base: number;
            discount: number;
            service: number;
            commentary: string;
            tax_base_iva: number;
            tax_base_iva_rate_0: number;
            tax_base_iva_exempt: number;
            tax_base_iva_not_subject: number;
            tax_base_irbpnr: number;
            rate_iva: number;
            tax_base_ice: number;
            tax_iva: number;
            code_iva: string;
            tax_irbpnr: number;
            tax_ice: number;
            total: number;
            price_type: string;
            export?: boolean;
            company_NIF: string;
            company_address: string;
            company_trade_name: string;
            company_business_name: string;
            company_branch_identification_number: string;
            company_branch_trade_name: string;
            company_branch_logo: string;
            company_branch_address: string;
            company_branch_email: string;
            company_branch_cellphone: string;
            company_branch_phone: string;
            client_document_number: string;
            client_trade_name: string;
            client_business_name: string;
            client_phone_code: string;
            client_address: string;
            client_cellphone: string;
            client_email: string;
            client_branch_code: string;
            client_branch_name: string;
            client_branch_address: string;
            client_branch_email: string;
            client_branch_cellphone: string;
            client_branch_phone: string;
            client_branch_phone_code: string;
            client_category_name: string;
            client_province_id?: string;
            client_canton_id?: string;
            client_parish_id?: string;
            client_province_code?: string;
            client_province_name?: string;
            client_canton_code?: string;
            client_canton_name?: string;
            client_parish_code?: string;
            client_parish_name?: string;
            contact_identification_number: string;
            contact_full_name: string;
            contact_phone_code: string;
            contact_cellphone: string;
            contact_email: string;
            seller_identification_number: string;
            seller_full_name: string;
            seller_address: string;
            seller_email: string[];
            seller_cellphone: string;
            enabled: boolean;
            created_at: number;
            created_user: string;
            reverse_status: boolean;
            deleted_at: number;
            default_price_list_id?: string;
            default_price_list_name?: string;
            default_price_list_type?: string;
            default_cost_center_id?: string;
            default_cost_center_code?: string;
            default_cost_center_name?: string;
            default_cost_center_father_code?: string;
            default_cost_center_father_name?: string;
            default_warehouse_id: string;
            default_discount_rate: number;
            credit_management: Item.CreditManagement;
        }
        namespace Item {
            interface CreditManagement {
                _id: string;
                client_id: string;
                invoice_id: string;
                credit: number;
                debit: number;
                retention: number;
                return: number;
                balance: number;
            }
        }
    }
    interface SendEmailParams {
        timezone: string;
        locale: string;
        emails?: string;
    }
    interface ChangeStatusBody {
        enabled: boolean;
        disabled_reason?: string;
    }
    interface ConfirmResponse {
        success: boolean;
        message: string;
        data?: any;
    }
    interface DownloadIndividualPdfParams {
        timezone: string;
        locale: string;
    }
    interface DownloadIndividualExcelParams {
        timezone: string;
        locale: string;
    }
}
